@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.053'; # VERSION
+our $VERSION = '0.054'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -19,12 +19,13 @@ sub opt_spec {
     my ($self, $app) = @_;
 
     return (
-        [ 'author=s'    => 'Your (alphanumeric) author ID'     ],
-        [ 'dryrun'      => 'Do not commit any changes'         ],
-        [ 'message|m=s' => 'Message to describe the change'    ],
-        [ 'norecurse|n' => 'Do not recursively pull prereqs'   ],
-        [ 'pin'         => 'Pin packages to the stack'         ],
-        [ 'stack|s=s'   => 'Put packages into this stack'      ],
+        [ 'author=s'    => 'Your (alphanumeric) author ID'       ],
+        [ 'dryrun'      => 'Do not commit any changes'           ],
+        [ 'message|m=s' => 'Message to describe the change'      ],
+        [ 'norecurse|n' => 'Do not recursively pull prereqs'     ],
+        [ 'pin'         => 'Pin packages to the stack'           ],
+        [ 'stack|s=s'   => 'Put packages into this stack'        ],
+        [ 'use-default-message|M' => 'Use the generated message' ],
     );
 }
 
@@ -52,7 +53,7 @@ App::Pinto::Command::add - add local archives to the repository
 
 =head1 VERSION
 
-version 0.053
+version 0.054
 
 =head1 SYNOPSIS
 
@@ -100,12 +101,13 @@ potentially impact the stack.
 
 =item -m TEXT
 
-Use TEXT as the revision history log message.  If you do not use
-C<--message> option, then you will be prompted to enter the message
-via your text editor.  Use the C<EDITOR> or C<VISUAL> environment
-variables to control which editor is used.  A log message is not
-required whenever the C<--dryrun> option is set, or if the action did
-not yield any changes to the repository.
+Use TEXT as the revision history log message.  If you do not use the
+C<--message> option or the C<--use-default-message> option, then you
+will be prompted to enter the message via your text editor.  Use the
+C<EDITOR> or C<VISUAL> environment variables to control which editor
+is used.  A log message is not required whenever the C<--dryrun>
+option is set, or if the action did not yield any changes to the
+repository.
 
 =item --norecurse
 
@@ -129,6 +131,15 @@ to the name of whichever stack is currently marked as the default
 stack.  Use the L<stacks|App::Pinto::Command::stacks> command
 to see the stacks in the repository.
 
+=item --use-default-message
+
+=item -M
+
+Use the default value for the revision history log message.  Pinto
+will generate a semi-informative log message just based on the command
+and its arguments.  If you set an explicit message with C<--message>,
+the C<--use-default-message> option will be silently ignored.
+
 =back
 
 =head1 AUTHOR
