@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.053'; # VERSION
+our $VERSION = '0.054'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -24,8 +24,9 @@ sub opt_spec {
 
     return (
         [ 'default'         => 'Make the new stack the default stack' ],
-        [ 'description|d=s' => 'Brief description of the stack' ],
-        [ 'message|m=s'     => 'Message to describe the change' ],
+        [ 'description|d=s' => 'Brief description of the stack'       ],
+        [ 'message|m=s'     => 'Message to describe the change'       ],
+        [ 'use-default-message|M' => 'Use the generated message'      ],
     );
 
 
@@ -67,7 +68,7 @@ App::Pinto::Command::copy - create a new stack by copying another
 
 =head1 VERSION
 
-version 0.053
+version 0.054
 
 =head1 SYNOPSIS
 
@@ -109,10 +110,20 @@ help explain the purpose of the stack.
 
 =item -m TEXT
 
-Use TEXT as the revision history log message.  If you do not use
-C<--message> option, then you will be prompted to enter the message
-via your text editor.  Use the C<EDITOR> or C<VISUAL> environment
-variables to control which editor is used.
+Use TEXT as the revision history log message.  If you do not use the
+C<--message> option or the C<--use-default-message> option, then you
+will be prompted to enter the message via your text editor.  Use the
+C<EDITOR> or C<VISUAL> environment variables to control which editor
+is used.
+
+=item --use-default-message
+
+=item -M
+
+Use the default value for the revision history log message.  Pinto
+will generate a semi-informative log message just based on the command
+and its arguments.  If you set an explicit message with C<--message>,
+the C<--use-default-message> option will be silently ignored.
 
 =back
 
