@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_04'; # VERSION
+our $VERSION = '0.054'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -25,20 +25,28 @@ sub validate_args {
     $self->usage_error('Must specify FROM_STACK and TO_STACK')
         if @{$args} != 2;
 
-    $opts->{from_stack} = $args->[0];
-    $opts->{to_stack}   = $args->[1];
-
     return 1;
 }
 
+#------------------------------------------------------------------------------
+
+sub execute {
+    my ($self, $opts, $args) = @_;
+
+    my %stacks = ( from_stack => $args->[0], to_stack => $args->[1] );
+    my $result = $self->pinto->run($self->action_name, %{$opts}, %stacks);
+
+    return $result->exit_status;
+}
+
 #------------------------------------------------------------------------------
 1;
 
-__END__
+
 
 =pod
 
-=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems
+=for :stopwords Jeffrey Thalhammer Imaginative Software Systems
 
 =head1 NAME
 
@@ -46,7 +54,7 @@ App::Pinto::Command::rename - change the name of a stack
 
 =head1 VERSION
 
-version 0.065_04
+version 0.054
 
 =head1 SYNOPSIS
 
@@ -56,12 +64,15 @@ version 0.065_04
 
 This command changes the name of an existing stack.  Once the name is
 changed, you will not be able to perform commands or access archives
-via the old stack name.
+via the old stack name.  Name changes are not recorded in the revision
+history, so the L<revert|App::Pinto::Command::revert> command will
+never cause the stack name to change back to its former value.
 
-See the L<new|App::Pinto::Command::new> command to create a new empty
-stack, or the L<copy|App::Pinto::Command::copy> command to duplicate
-an existing stack, or the L<props|App::Pinto::Command::props> command
-to change a stack's properties after it has been created.
+Please see the L<new|App::Pinto::Command::new> command to create a new
+empty stack, or the L<edit|App::Pinto::Command::edit> command to
+change a stack's properties after it has been created, or the
+L<copy|App::Pinto::Command::copy> command to duplicate an existing
+stack.
 
 =head1 COMMAND ARGUMENTS
 
@@ -75,7 +86,7 @@ NONE.
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <jeff@stratopan.com>
+Jeffrey Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -85,3 +96,7 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
